import importlib
import logging

from nicevirus.backends.base import BaseBackend


log = logging.getLogger(__name__)


class Scanner(object):
    def __init__(self, backends):
        self.backends = {}

        for backend in backends:
            self.load_backend(backend)

    def load_backend(self, name, config=None):
        config = config or {}
        module = importlib.import_module(name)

        for obj in map(lambda k: getattr(module, k), dir(module)):
            if obj == BaseBackend or not issubclass(obj, BaseBackend):
                continue

            self.backends[name] = obj(config)
            break
        else:
            log.error('Failed to load backend from module %s', name)
            return
        log.info('Successfully loaded module %s', name)

    def scan(self, path):
        return {k: v.scan(path) for k, v in self.backends.iteritems()}

    def check(self):
        return {k: v.check() for k, v in self.backends.iteritems()}
